class App:
    Annotation = 'App::Annotation'
    AnnotationLabel = 'App::AnnotationLabel'
    ConditionalExpression = 'App::ConditionalExpression'
    ConstantExpression = 'App::ConstantExpression'
    Document = 'App::Document'
    DocumentObject = 'App::DocumentObject'
    DocumentObjectExtension = 'App::DocumentObjectExtension'
    DocumentObjectFileIncluded = 'App::DocumentObjectFileIncluded'
    DocumentObjectGroup = 'App::DocumentObjectGroup'
    DocumentObjectGroupPython = 'App::DocumentObjectGroupPython'
    Expression = 'App::Expression'
    Extension = 'App::Extension'
    ExtensionContainer = 'App::ExtensionContainer'
    FeaturePython = 'App::FeaturePython'
    FeatureTest = 'App::FeatureTest'
    FeatureTestException = 'App::FeatureTestException'
    FunctionExpression = 'App::FunctionExpression'
    GeoFeature = 'App::GeoFeature'
    GeoFeatureGroupExtension = 'App::GeoFeatureGroupExtension'
    GeoFeatureGroupExtensionPython = 'App::GeoFeatureGroupExtensionPython'
    GeometryPython = 'App::GeometryPython'
    GroupExtension = 'App::GroupExtension'
    GroupExtensionPython = 'App::GroupExtensionPython'
    InventorObject = 'App::InventorObject'
    Line = 'App::Line'
    Link = 'App::Link'
    LinkBaseExtension = 'App::LinkBaseExtension'
    LinkBaseExtensionPython = 'App::LinkBaseExtensionPython'
    LinkElement = 'App::LinkElement'
    LinkElementPython = 'App::LinkElementPython'
    LinkExtension = 'App::LinkExtension'
    LinkExtensionPython = 'App::LinkExtensionPython'
    LinkGroup = 'App::LinkGroup'
    LinkGroupPython = 'App::LinkGroupPython'
    LinkPython = 'App::LinkPython'
    MaterialObject = 'App::MaterialObject'
    MaterialObjectPython = 'App::MaterialObjectPython'
    MeasureDistance = 'App::MeasureDistance'
    NumberExpression = 'App::NumberExpression'
    OperatorExpression = 'App::OperatorExpression'
    Origin = 'App::Origin'
    OriginFeature = 'App::OriginFeature'
    OriginGroupExtension = 'App::OriginGroupExtension'
    OriginGroupExtensionPython = 'App::OriginGroupExtensionPython'
    Part = 'App::Part'
    Placement = 'App::Placement'
    PlacementPython = 'App::PlacementPython'
    Plane = 'App::Plane'
    Property = 'App::Property'
    PropertyAcceleration = 'App::PropertyAcceleration'
    PropertyAngle = 'App::PropertyAngle'
    PropertyArea = 'App::PropertyArea'
    PropertyBool = 'App::PropertyBool'
    PropertyBoolList = 'App::PropertyBoolList'
    PropertyColor = 'App::PropertyColor'
    PropertyColorList = 'App::PropertyColorList'
    PropertyComplexGeoData = 'App::PropertyComplexGeoData'
    PropertyContainer = 'App::PropertyContainer'
    PropertyDirection = 'App::PropertyDirection'
    PropertyDistance = 'App::PropertyDistance'
    PropertyEnumeration = 'App::PropertyEnumeration'
    PropertyExpressionContainer = 'App::PropertyExpressionContainer'
    PropertyExpressionEngine = 'App::PropertyExpressionEngine'
    PropertyFile = 'App::PropertyFile'
    PropertyFileIncluded = 'App::PropertyFileIncluded'
    PropertyFloat = 'App::PropertyFloat'
    PropertyFloatConstraint = 'App::PropertyFloatConstraint'
    PropertyFloatList = 'App::PropertyFloatList'
    PropertyFont = 'App::PropertyFont'
    PropertyForce = 'App::PropertyForce'
    PropertyFrequency = 'App::PropertyFrequency'
    PropertyGeometry = 'App::PropertyGeometry'
    PropertyInteger = 'App::PropertyInteger'
    PropertyIntegerConstraint = 'App::PropertyIntegerConstraint'
    PropertyIntegerList = 'App::PropertyIntegerList'
    PropertyIntegerSet = 'App::PropertyIntegerSet'
    PropertyLength = 'App::PropertyLength'
    PropertyLink = 'App::PropertyLink'
    PropertyLinkBase = 'App::PropertyLinkBase'
    PropertyLinkChild = 'App::PropertyLinkChild'
    PropertyLinkGlobal = 'App::PropertyLinkGlobal'
    PropertyLinkHidden = 'App::PropertyLinkHidden'
    PropertyLinkList = 'App::PropertyLinkList'
    PropertyLinkListBase = 'App::PropertyLinkListBase'
    PropertyLinkListChild = 'App::PropertyLinkListChild'
    PropertyLinkListGlobal = 'App::PropertyLinkListGlobal'
    PropertyLinkListHidden = 'App::PropertyLinkListHidden'
    PropertyLinkSub = 'App::PropertyLinkSub'
    PropertyLinkSubChild = 'App::PropertyLinkSubChild'
    PropertyLinkSubGlobal = 'App::PropertyLinkSubGlobal'
    PropertyLinkSubHidden = 'App::PropertyLinkSubHidden'
    PropertyLinkSubList = 'App::PropertyLinkSubList'
    PropertyLinkSubListChild = 'App::PropertyLinkSubListChild'
    PropertyLinkSubListGlobal = 'App::PropertyLinkSubListGlobal'
    PropertyLinkSubListHidden = 'App::PropertyLinkSubListHidden'
    PropertyLists = 'App::PropertyLists'
    PropertyMap = 'App::PropertyMap'
    PropertyMaterial = 'App::PropertyMaterial'
    PropertyMaterialList = 'App::PropertyMaterialList'
    PropertyMatrix = 'App::PropertyMatrix'
    PropertyPath = 'App::PropertyPath'
    PropertyPercent = 'App::PropertyPercent'
    PropertyPersistentObject = 'App::PropertyPersistentObject'
    PropertyPlacement = 'App::PropertyPlacement'
    PropertyPlacementLink = 'App::PropertyPlacementLink'
    PropertyPlacementList = 'App::PropertyPlacementList'
    PropertyPosition = 'App::PropertyPosition'
    PropertyPrecision = 'App::PropertyPrecision'
    PropertyPressure = 'App::PropertyPressure'
    PropertyPythonObject = 'App::PropertyPythonObject'
    PropertyQuantity = 'App::PropertyQuantity'
    PropertyQuantityConstraint = 'App::PropertyQuantityConstraint'
    PropertySpeed = 'App::PropertySpeed'
    PropertyString = 'App::PropertyString'
    PropertyStringList = 'App::PropertyStringList'
    PropertyUUID = 'App::PropertyUUID'
    PropertyVacuumPermittivity = 'App::PropertyVacuumPermittivity'
    PropertyVector = 'App::PropertyVector'
    PropertyVectorDistance = 'App::PropertyVectorDistance'
    PropertyVectorList = 'App::PropertyVectorList'
    PropertyVolume = 'App::PropertyVolume'
    PropertyXLink = 'App::PropertyXLink'
    PropertyXLinkContainer = 'App::PropertyXLinkContainer'
    PropertyXLinkList = 'App::PropertyXLinkList'
    PropertyXLinkSub = 'App::PropertyXLinkSub'
    PropertyXLinkSubList = 'App::PropertyXLinkSubList'
    PyObjectExpression = 'App::PyObjectExpression'
    RangeExpression = 'App::RangeExpression'
    StringExpression = 'App::StringExpression'
    TextDocument = 'App::TextDocument'
    TransactionalObject = 'App::TransactionalObject'
    UnitExpression = 'App::UnitExpression'
    VRMLObject = 'App::VRMLObject'
    VariableExpression = 'App::VariableExpression'


class Assembly:
    Constraint = 'Assembly::Constraint'
    ConstraintGroup = 'Assembly::ConstraintGroup'
    Item = 'Assembly::Item'
    Product = 'Assembly::Product'
    ProductRef = 'Assembly::ProductRef'


class AssemblyGui:
    ViewProviderConstraint = 'AssemblyGui::ViewProviderConstraint'
    ViewProviderConstraintGroup = 'AssemblyGui::ViewProviderConstraintGroup'
    ViewProviderItem = 'AssemblyGui::ViewProviderItem'
    ViewProviderProduct = 'AssemblyGui::ViewProviderProduct'
    ViewProviderProductRef = 'AssemblyGui::ViewProviderProductRef'
    Workbench = 'AssemblyGui::Workbench'


class Attacher:
    AttachEngine = 'Attacher::AttachEngine'
    AttachEngine3D = 'Attacher::AttachEngine3D'
    AttachEngineLine = 'Attacher::AttachEngineLine'
    AttachEnginePlane = 'Attacher::AttachEnginePlane'
    AttachEnginePoint = 'Attacher::AttachEnginePoint'


class Base:
    AbortException = 'Base::AbortException'
    BaseClass = 'Base::BaseClass'
    Exception = 'Base::Exception'
    Persistence = 'Base::Persistence'
    Type = 'Base::Type'


class CamGui:
    Workbench = 'CamGui::Workbench'


class CloudGui:
    Workbench = 'CloudGui::Workbench'


class Common:
    ApplicationIndex = 'ApplicationIndex'
    BlenderNavigationStyle = 'BlenderNavigationStyle'
    CADNavigationStyle = 'CADNavigationStyle'
    DocumentIndex = 'DocumentIndex'
    DocumentModelIndex = 'DocumentModelIndex'
    GLFlagWindow = 'GLFlagWindow'
    GLGraphicsItem = 'GLGraphicsItem'
    GestureNavigationStyle = 'GestureNavigationStyle'
    InventorNavigationStyle = 'InventorNavigationStyle'
    MayaGestureNavigationStyle = 'MayaGestureNavigationStyle'
    NavigationStyle = 'NavigationStyle'
    OpenCascadeNavigationStyle = 'OpenCascadeNavigationStyle'
    PathSelectionObserver = 'PathSelectionObserver'
    PropertyAngleItem = 'PropertyAngleItem'
    PropertyBoolItem = 'PropertyBoolItem'
    PropertyColorItem = 'PropertyColorItem'
    PropertyDirectionItem = 'PropertyDirectionItem'
    PropertyEnumItem = 'PropertyEnumItem'
    PropertyFileItem = 'PropertyFileItem'
    PropertyFloatConstraintItem = 'PropertyFloatConstraintItem'
    PropertyFloatItem = 'PropertyFloatItem'
    PropertyFloatListItem = 'PropertyFloatListItem'
    PropertyFontItem = 'PropertyFontItem'
    PropertyIntegerConstraintItem = 'PropertyIntegerConstraintItem'
    PropertyIntegerItem = 'PropertyIntegerItem'
    PropertyIntegerListItem = 'PropertyIntegerListItem'
    PropertyItem = 'PropertyItem'
    PropertyLinkItem = 'PropertyLinkItem'
    PropertyLinkListItem = 'PropertyLinkListItem'
    PropertyMaterialItem = 'PropertyMaterialItem'
    PropertyMaterialListItem = 'PropertyMaterialListItem'
    PropertyMatrixItem = 'PropertyMatrixItem'
    PropertyPathItem = 'PropertyPathItem'
    PropertyPlacementItem = 'PropertyPlacementItem'
    PropertyPositionItem = 'PropertyPositionItem'
    PropertyPrecisionItem = 'PropertyPrecisionItem'
    PropertySeparatorItem = 'PropertySeparatorItem'
    PropertyStringItem = 'PropertyStringItem'
    PropertyStringListItem = 'PropertyStringListItem'
    PropertyTransientFileItem = 'PropertyTransientFileItem'
    PropertyUnitConstraintItem = 'PropertyUnitConstraintItem'
    PropertyUnitItem = 'PropertyUnitItem'
    PropertyVectorDistanceItem = 'PropertyVectorDistanceItem'
    PropertyVectorItem = 'PropertyVectorItem'
    PropertyVectorListItem = 'PropertyVectorListItem'
    RevitNavigationStyle = 'RevitNavigationStyle'
    SelectionObject = 'SelectionObject'
    SoDB = 'SoDB'
    SoFCDB = 'SoFCDB'
    SoInteraction = 'SoInteraction'
    SoNodeKit = 'SoNodeKit'
    TouchpadNavigationStyle = 'TouchpadNavigationStyle'
    UserNavigationStyle = 'UserNavigationStyle'
    ViewProviderIndex = 'ViewProviderIndex'
    WorkflowManager = 'WorkflowManager'
    voidActionBox = 'voidActionBox'
    voidActionLabel = 'voidActionLabel'
    voidBelongToGeom = 'voidBelongToGeom'
    voidDocumentProtector = 'voidDocumentProtector'
    voidDownloadItem = 'voidDownloadItem'
    voidExpressionCompleter = 'voidExpressionCompleter'
    voidLyingOnGeom = 'voidLyingOnGeom'
    voidView3DInventorViewer = 'voidView3DInventorViewer'
    voidWorkflowManager = 'voidWorkflowManager'
    voidiisTaskBox = 'voidiisTaskBox'


class Data:
    ComplexGeoData = 'Data::ComplexGeoData'
    Segment = 'Data::Segment'


class Drawing:
    FeatureClip = 'Drawing::FeatureClip'
    FeaturePage = 'Drawing::FeaturePage'
    FeatureProjection = 'Drawing::FeatureProjection'
    FeatureView = 'Drawing::FeatureView'
    FeatureViewAnnotation = 'Drawing::FeatureViewAnnotation'
    FeatureViewPart = 'Drawing::FeatureViewPart'
    FeatureViewPartPython = 'Drawing::FeatureViewPartPython'
    FeatureViewPython = 'Drawing::FeatureViewPython'
    FeatureViewSpreadsheet = 'Drawing::FeatureViewSpreadsheet'
    FeatureViewSymbol = 'Drawing::FeatureViewSymbol'
    PageGroup = 'Drawing::PageGroup'


class DrawingGui:
    ViewProviderDrawingClip = 'DrawingGui::ViewProviderDrawingClip'
    ViewProviderDrawingPage = 'DrawingGui::ViewProviderDrawingPage'
    ViewProviderDrawingView = 'DrawingGui::ViewProviderDrawingView'
    ViewProviderDrawingViewPython = 'DrawingGui::ViewProviderDrawingViewPython'
    Workbench = 'DrawingGui::Workbench'


class Fem:
    Constraint = 'Fem::Constraint'
    ConstraintBearing = 'Fem::ConstraintBearing'
    ConstraintContact = 'Fem::ConstraintContact'
    ConstraintDisplacement = 'Fem::ConstraintDisplacement'
    ConstraintFixed = 'Fem::ConstraintFixed'
    ConstraintFluidBoundary = 'Fem::ConstraintFluidBoundary'
    ConstraintForce = 'Fem::ConstraintForce'
    ConstraintGear = 'Fem::ConstraintGear'
    ConstraintHeatflux = 'Fem::ConstraintHeatflux'
    ConstraintInitialTemperature = 'Fem::ConstraintInitialTemperature'
    ConstraintPlaneRotation = 'Fem::ConstraintPlaneRotation'
    ConstraintPressure = 'Fem::ConstraintPressure'
    ConstraintPulley = 'Fem::ConstraintPulley'
    ConstraintPython = 'Fem::ConstraintPython'
    ConstraintSpring = 'Fem::ConstraintSpring'
    ConstraintTemperature = 'Fem::ConstraintTemperature'
    ConstraintTransform = 'Fem::ConstraintTransform'
    DocumentObject = 'Fem::DocumentObject'
    FeaturePython = 'Fem::FeaturePython'
    FemAnalysis = 'Fem::FemAnalysis'
    FemAnalysisPython = 'Fem::FemAnalysisPython'
    FemMesh = 'Fem::FemMesh'
    FemMeshObject = 'Fem::FemMeshObject'
    FemMeshObjectPython = 'Fem::FemMeshObjectPython'
    FemMeshShapeNetgenObject = 'Fem::FemMeshShapeNetgenObject'
    FemMeshShapeObject = 'Fem::FemMeshShapeObject'
    FemPostClipFilter = 'Fem::FemPostClipFilter'
    FemPostCutFilter = 'Fem::FemPostCutFilter'
    FemPostDataAlongLineFilter = 'Fem::FemPostDataAlongLineFilter'
    FemPostDataAtPointFilter = 'Fem::FemPostDataAtPointFilter'
    FemPostFilter = 'Fem::FemPostFilter'
    FemPostFunction = 'Fem::FemPostFunction'
    FemPostFunctionProvider = 'Fem::FemPostFunctionProvider'
    FemPostObject = 'Fem::FemPostObject'
    FemPostPipeline = 'Fem::FemPostPipeline'
    FemPostPlaneFunction = 'Fem::FemPostPlaneFunction'
    FemPostScalarClipFilter = 'Fem::FemPostScalarClipFilter'
    FemPostSphereFunction = 'Fem::FemPostSphereFunction'
    FemPostWarpVectorFilter = 'Fem::FemPostWarpVectorFilter'
    FemResultObject = 'Fem::FemResultObject'
    FemResultObjectPython = 'Fem::FemResultObjectPython'
    FemSetElementsObject = 'Fem::FemSetElementsObject'
    FemSetFacesObject = 'Fem::FemSetFacesObject'
    FemSetGeometryObject = 'Fem::FemSetGeometryObject'
    FemSetNodesObject = 'Fem::FemSetNodesObject'
    FemSetObject = 'Fem::FemSetObject'
    FemSolverObject = 'Fem::FemSolverObject'
    FemSolverObjectPython = 'Fem::FemSolverObjectPython'
    PropertyFemMesh = 'Fem::PropertyFemMesh'
    PropertyPostDataObject = 'Fem::PropertyPostDataObject'


class FemGui:
    PropertyFemMeshItem = 'FemGui::PropertyFemMeshItem'
    ViewProviderFemAnalysis = 'FemGui::ViewProviderFemAnalysis'
    ViewProviderFemAnalysisPython = 'FemGui::ViewProviderFemAnalysisPython'
    ViewProviderFemConstraint = 'FemGui::ViewProviderFemConstraint'
    ViewProviderFemConstraintBearing = 'FemGui::ViewProviderFemConstraintBearing'
    ViewProviderFemConstraintContact = 'FemGui::ViewProviderFemConstraintContact'
    ViewProviderFemConstraintDisplacement = 'FemGui::ViewProviderFemConstraintDisplacement'
    ViewProviderFemConstraintFixed = 'FemGui::ViewProviderFemConstraintFixed'
    ViewProviderFemConstraintFluidBoundary = 'FemGui::ViewProviderFemConstraintFluidBoundary'
    ViewProviderFemConstraintForce = 'FemGui::ViewProviderFemConstraintForce'
    ViewProviderFemConstraintGear = 'FemGui::ViewProviderFemConstraintGear'
    ViewProviderFemConstraintHeatflux = 'FemGui::ViewProviderFemConstraintHeatflux'
    ViewProviderFemConstraintInitialTemperature = 'FemGui::ViewProviderFemConstraintInitialTemperature'
    ViewProviderFemConstraintPlaneRotation = 'FemGui::ViewProviderFemConstraintPlaneRotation'
    ViewProviderFemConstraintPressure = 'FemGui::ViewProviderFemConstraintPressure'
    ViewProviderFemConstraintPulley = 'FemGui::ViewProviderFemConstraintPulley'
    ViewProviderFemConstraintPython = 'FemGui::ViewProviderFemConstraintPython'
    ViewProviderFemConstraintSpring = 'FemGui::ViewProviderFemConstraintSpring'
    ViewProviderFemConstraintTemperature = 'FemGui::ViewProviderFemConstraintTemperature'
    ViewProviderFemConstraintTransform = 'FemGui::ViewProviderFemConstraintTransform'
    ViewProviderFemMesh = 'FemGui::ViewProviderFemMesh'
    ViewProviderFemMeshPython = 'FemGui::ViewProviderFemMeshPython'
    ViewProviderFemMeshShape = 'FemGui::ViewProviderFemMeshShape'
    ViewProviderFemMeshShapeNetgen = 'FemGui::ViewProviderFemMeshShapeNetgen'
    ViewProviderFemPostClip = 'FemGui::ViewProviderFemPostClip'
    ViewProviderFemPostCut = 'FemGui::ViewProviderFemPostCut'
    ViewProviderFemPostDataAlongLine = 'FemGui::ViewProviderFemPostDataAlongLine'
    ViewProviderFemPostDataAtPoint = 'FemGui::ViewProviderFemPostDataAtPoint'
    ViewProviderFemPostFunction = 'FemGui::ViewProviderFemPostFunction'
    ViewProviderFemPostFunctionProvider = 'FemGui::ViewProviderFemPostFunctionProvider'
    ViewProviderFemPostObject = 'FemGui::ViewProviderFemPostObject'
    ViewProviderFemPostPipeline = 'FemGui::ViewProviderFemPostPipeline'
    ViewProviderFemPostPlaneFunction = 'FemGui::ViewProviderFemPostPlaneFunction'
    ViewProviderFemPostScalarClip = 'FemGui::ViewProviderFemPostScalarClip'
    ViewProviderFemPostSphereFunction = 'FemGui::ViewProviderFemPostSphereFunction'
    ViewProviderFemPostWarpVector = 'FemGui::ViewProviderFemPostWarpVector'
    ViewProviderResult = 'FemGui::ViewProviderResult'
    ViewProviderResultPython = 'FemGui::ViewProviderResultPython'
    ViewProviderSetElements = 'FemGui::ViewProviderSetElements'
    ViewProviderSetFaces = 'FemGui::ViewProviderSetFaces'
    ViewProviderSetGeometry = 'FemGui::ViewProviderSetGeometry'
    ViewProviderSetNodes = 'FemGui::ViewProviderSetNodes'
    ViewProviderSolver = 'FemGui::ViewProviderSolver'
    ViewProviderSolverPython = 'FemGui::ViewProviderSolverPython'
    Workbench = 'FemGui::Workbench'


class Gui:
    AbstractSplitView = 'Gui::AbstractSplitView'
    AxisOrigin = 'Gui::AxisOrigin'
    BaseView = 'Gui::BaseView'
    BlankWorkbench = 'Gui::BlankWorkbench'
    LinkView = 'Gui::LinkView'
    MDIView = 'Gui::MDIView'
    NoneWorkbench = 'Gui::NoneWorkbench'
    PythonBaseWorkbench = 'Gui::PythonBaseWorkbench'
    PythonBlankWorkbench = 'Gui::PythonBlankWorkbench'
    PythonWorkbench = 'Gui::PythonWorkbench'
    SoFCDB = 'Gui::SoFCDB'
    SplitView3DInventor = 'Gui::SplitView3DInventor'
    StdWorkbench = 'Gui::StdWorkbench'
    TestWorkbench = 'Gui::TestWorkbench'
    TextDocumentEditorView = 'Gui::TextDocumentEditorView'
    View3DInventor = 'Gui::View3DInventor'
    ViewProvider = 'Gui::ViewProvider'
    ViewProviderAnnotation = 'Gui::ViewProviderAnnotation'
    ViewProviderAnnotationLabel = 'Gui::ViewProviderAnnotationLabel'
    ViewProviderDocumentObject = 'Gui::ViewProviderDocumentObject'
    ViewProviderDocumentObjectGroup = 'Gui::ViewProviderDocumentObjectGroup'
    ViewProviderDocumentObjectGroupPython = 'Gui::ViewProviderDocumentObjectGroupPython'
    ViewProviderDragger = 'Gui::ViewProviderDragger'
    ViewProviderExtension = 'Gui::ViewProviderExtension'
    ViewProviderExtensionPython = 'Gui::ViewProviderExtensionPython'
    ViewProviderExtern = 'Gui::ViewProviderExtern'
    ViewProviderFeature = 'Gui::ViewProviderFeature'
    ViewProviderGeoFeatureGroup = 'Gui::ViewProviderGeoFeatureGroup'
    ViewProviderGeoFeatureGroupExtension = 'Gui::ViewProviderGeoFeatureGroupExtension'
    ViewProviderGeoFeatureGroupExtensionPython = 'Gui::ViewProviderGeoFeatureGroupExtensionPython'
    ViewProviderGeoFeatureGroupPython = 'Gui::ViewProviderGeoFeatureGroupPython'
    ViewProviderGeometryObject = 'Gui::ViewProviderGeometryObject'
    ViewProviderGroupExtension = 'Gui::ViewProviderGroupExtension'
    ViewProviderGroupExtensionPython = 'Gui::ViewProviderGroupExtensionPython'
    ViewProviderInventorObject = 'Gui::ViewProviderInventorObject'
    ViewProviderLine = 'Gui::ViewProviderLine'
    ViewProviderLink = 'Gui::ViewProviderLink'
    ViewProviderLinkObserver = 'Gui::ViewProviderLinkObserver'
    ViewProviderLinkPython = 'Gui::ViewProviderLinkPython'
    ViewProviderMaterialObject = 'Gui::ViewProviderMaterialObject'
    ViewProviderMaterialObjectPython = 'Gui::ViewProviderMaterialObjectPython'
    ViewProviderMeasureDistance = 'Gui::ViewProviderMeasureDistance'
    ViewProviderOrigin = 'Gui::ViewProviderOrigin'
    ViewProviderOriginFeature = 'Gui::ViewProviderOriginFeature'
    ViewProviderOriginGroup = 'Gui::ViewProviderOriginGroup'
    ViewProviderOriginGroupExtension = 'Gui::ViewProviderOriginGroupExtension'
    ViewProviderOriginGroupExtensionPython = 'Gui::ViewProviderOriginGroupExtensionPython'
    ViewProviderPart = 'Gui::ViewProviderPart'
    ViewProviderPlacement = 'Gui::ViewProviderPlacement'
    ViewProviderPlacementPython = 'Gui::ViewProviderPlacementPython'
    ViewProviderPlane = 'Gui::ViewProviderPlane'
    ViewProviderPointMarker = 'Gui::ViewProviderPointMarker'
    ViewProviderPythonFeature = 'Gui::ViewProviderPythonFeature'
    ViewProviderPythonGeometry = 'Gui::ViewProviderPythonGeometry'
    ViewProviderTextDocument = 'Gui::ViewProviderTextDocument'
    ViewProviderVRMLObject = 'Gui::ViewProviderVRMLObject'
    Workbench = 'Gui::Workbench'


class Image:
    ImagePlane = 'Image::ImagePlane'


class ImageGui:
    ViewProviderImagePlane = 'ImageGui::ViewProviderImagePlane'
    Workbench = 'ImageGui::Workbench'


class ImportGui:
    Workbench = 'ImportGui::Workbench'


class Inspection:
    Feature = 'Inspection::Feature'
    Group = 'Inspection::Group'
    PropertyDistanceList = 'Inspection::PropertyDistanceList'


class InspectionGui:
    ViewProviderInspection = 'InspectionGui::ViewProviderInspection'
    ViewProviderInspectionGroup = 'InspectionGui::ViewProviderInspectionGroup'
    Workbench = 'InspectionGui::Workbench'


class Measure:
    Measurement = 'Measure::Measurement'


class Mesh:
    Cone = 'Mesh::Cone'
    Cube = 'Mesh::Cube'
    Curvature = 'Mesh::Curvature'
    Cylinder = 'Mesh::Cylinder'
    Ellipsoid = 'Mesh::Ellipsoid'
    Export = 'Mesh::Export'
    Feature = 'Mesh::Feature'
    FeatureCustom = 'Mesh::FeatureCustom'
    FeaturePython = 'Mesh::FeaturePython'
    FillHoles = 'Mesh::FillHoles'
    FixDefects = 'Mesh::FixDefects'
    FixDeformations = 'Mesh::FixDeformations'
    FixDegenerations = 'Mesh::FixDegenerations'
    FixDuplicatedFaces = 'Mesh::FixDuplicatedFaces'
    FixDuplicatedPoints = 'Mesh::FixDuplicatedPoints'
    FixIndices = 'Mesh::FixIndices'
    FixNonManifolds = 'Mesh::FixNonManifolds'
    FlipNormals = 'Mesh::FlipNormals'
    HarmonizeNormals = 'Mesh::HarmonizeNormals'
    Import = 'Mesh::Import'
    MeshObject = 'Mesh::MeshObject'
    MeshSegment = 'Mesh::MeshSegment'
    PropertyCurvatureList = 'Mesh::PropertyCurvatureList'
    PropertyMeshKernel = 'Mesh::PropertyMeshKernel'
    PropertyNormalList = 'Mesh::PropertyNormalList'
    RemoveComponents = 'Mesh::RemoveComponents'
    SegmentByMesh = 'Mesh::SegmentByMesh'
    SetOperations = 'Mesh::SetOperations'
    Sphere = 'Mesh::Sphere'
    Torus = 'Mesh::Torus'
    Transform = 'Mesh::Transform'
    TransformDemolding = 'Mesh::TransformDemolding'


class MeshGui:
    PropertyMeshKernelItem = 'MeshGui::PropertyMeshKernelItem'
    ViewProviderExport = 'MeshGui::ViewProviderExport'
    ViewProviderIndexedFaceSet = 'MeshGui::ViewProviderIndexedFaceSet'
    ViewProviderMesh = 'MeshGui::ViewProviderMesh'
    ViewProviderMeshCurvature = 'MeshGui::ViewProviderMeshCurvature'
    ViewProviderMeshDefects = 'MeshGui::ViewProviderMeshDefects'
    ViewProviderMeshDegenerations = 'MeshGui::ViewProviderMeshDegenerations'
    ViewProviderMeshDuplicatedFaces = 'MeshGui::ViewProviderMeshDuplicatedFaces'
    ViewProviderMeshDuplicatedPoints = 'MeshGui::ViewProviderMeshDuplicatedPoints'
    ViewProviderMeshFaceSet = 'MeshGui::ViewProviderMeshFaceSet'
    ViewProviderMeshFolds = 'MeshGui::ViewProviderMeshFolds'
    ViewProviderMeshIndices = 'MeshGui::ViewProviderMeshIndices'
    ViewProviderMeshNonManifoldPoints = 'MeshGui::ViewProviderMeshNonManifoldPoints'
    ViewProviderMeshNonManifolds = 'MeshGui::ViewProviderMeshNonManifolds'
    ViewProviderMeshObject = 'MeshGui::ViewProviderMeshObject'
    ViewProviderMeshOrientation = 'MeshGui::ViewProviderMeshOrientation'
    ViewProviderMeshSelfIntersections = 'MeshGui::ViewProviderMeshSelfIntersections'
    ViewProviderMeshTransform = 'MeshGui::ViewProviderMeshTransform'
    ViewProviderMeshTransformDemolding = 'MeshGui::ViewProviderMeshTransformDemolding'
    ViewProviderPython = 'MeshGui::ViewProviderPython'
    Workbench = 'MeshGui::Workbench'


class MeshPartGui:
    ViewProviderCurveOnMesh = 'MeshPartGui::ViewProviderCurveOnMesh'
    Workbench = 'MeshPartGui::Workbench'


class Part:
    AttachExtension = 'Part::AttachExtension'
    AttachExtensionPython = 'Part::AttachExtensionPython'
    BodyBase = 'Part::BodyBase'
    Boolean = 'Part::Boolean'
    Box = 'Part::Box'
    Chamfer = 'Part::Chamfer'
    Circle = 'Part::Circle'
    Common = 'Part::Common'
    Compound = 'Part::Compound'
    Compound2 = 'Part::Compound2'
    Cone = 'Part::Cone'
    CurveNet = 'Part::CurveNet'
    CustomFeature = 'Part::CustomFeature'
    CustomFeaturePython = 'Part::CustomFeaturePython'
    Cut = 'Part::Cut'
    Cylinder = 'Part::Cylinder'
    Datum = 'Part::Datum'
    Ellipse = 'Part::Ellipse'
    Ellipsoid = 'Part::Ellipsoid'
    Extrusion = 'Part::Extrusion'
    Face = 'Part::Face'
    FaceMaker = 'Part::FaceMaker'
    FaceMakerBullseye = 'Part::FaceMakerBullseye'
    FaceMakerCheese = 'Part::FaceMakerCheese'
    FaceMakerExtrusion = 'Part::FaceMakerExtrusion'
    FaceMakerPublic = 'Part::FaceMakerPublic'
    FaceMakerSimple = 'Part::FaceMakerSimple'
    Feature = 'Part::Feature'
    FeatureExt = 'Part::FeatureExt'
    FeatureGeometrySet = 'Part::FeatureGeometrySet'
    FeaturePython = 'Part::FeaturePython'
    Fillet = 'Part::Fillet'
    FilletBase = 'Part::FilletBase'
    Fuse = 'Part::Fuse'
    Geom2dArcOfCircle = 'Part::Geom2dArcOfCircle'
    Geom2dArcOfConic = 'Part::Geom2dArcOfConic'
    Geom2dArcOfEllipse = 'Part::Geom2dArcOfEllipse'
    Geom2dArcOfHyperbola = 'Part::Geom2dArcOfHyperbola'
    Geom2dArcOfParabola = 'Part::Geom2dArcOfParabola'
    Geom2dBSplineCurve = 'Part::Geom2dBSplineCurve'
    Geom2dBezierCurve = 'Part::Geom2dBezierCurve'
    Geom2dCircle = 'Part::Geom2dCircle'
    Geom2dConic = 'Part::Geom2dConic'
    Geom2dCurve = 'Part::Geom2dCurve'
    Geom2dEllipse = 'Part::Geom2dEllipse'
    Geom2dHyperbola = 'Part::Geom2dHyperbola'
    Geom2dLine = 'Part::Geom2dLine'
    Geom2dLineSegment = 'Part::Geom2dLineSegment'
    Geom2dOffsetCurve = 'Part::Geom2dOffsetCurve'
    Geom2dParabola = 'Part::Geom2dParabola'
    Geom2dPoint = 'Part::Geom2dPoint'
    Geom2dTrimmedCurve = 'Part::Geom2dTrimmedCurve'
    GeomArcOfCircle = 'Part::GeomArcOfCircle'
    GeomArcOfConic = 'Part::GeomArcOfConic'
    GeomArcOfEllipse = 'Part::GeomArcOfEllipse'
    GeomArcOfHyperbola = 'Part::GeomArcOfHyperbola'
    GeomArcOfParabola = 'Part::GeomArcOfParabola'
    GeomBSplineCurve = 'Part::GeomBSplineCurve'
    GeomBSplineSurface = 'Part::GeomBSplineSurface'
    GeomBezierCurve = 'Part::GeomBezierCurve'
    GeomBezierSurface = 'Part::GeomBezierSurface'
    GeomBoundedCurve = 'Part::GeomBoundedCurve'
    GeomCircle = 'Part::GeomCircle'
    GeomCone = 'Part::GeomCone'
    GeomConic = 'Part::GeomConic'
    GeomCurve = 'Part::GeomCurve'
    GeomCylinder = 'Part::GeomCylinder'
    GeomEllipse = 'Part::GeomEllipse'
    GeomHyperbola = 'Part::GeomHyperbola'
    GeomLine = 'Part::GeomLine'
    GeomLineSegment = 'Part::GeomLineSegment'
    GeomOffsetCurve = 'Part::GeomOffsetCurve'
    GeomOffsetSurface = 'Part::GeomOffsetSurface'
    GeomParabola = 'Part::GeomParabola'
    GeomPlane = 'Part::GeomPlane'
    GeomPlateSurface = 'Part::GeomPlateSurface'
    GeomPoint = 'Part::GeomPoint'
    GeomSphere = 'Part::GeomSphere'
    GeomSurface = 'Part::GeomSurface'
    GeomSurfaceOfExtrusion = 'Part::GeomSurfaceOfExtrusion'
    GeomSurfaceOfRevolution = 'Part::GeomSurfaceOfRevolution'
    GeomToroid = 'Part::GeomToroid'
    GeomTrimmedCurve = 'Part::GeomTrimmedCurve'
    GeomTrimmedSurface = 'Part::GeomTrimmedSurface'
    Geometry = 'Part::Geometry'
    Geometry2d = 'Part::Geometry2d'
    GeometryBoolExtension = 'Part::GeometryBoolExtension'
    GeometryDoubleExtension = 'Part::GeometryDoubleExtension'
    GeometryExtension = 'Part::GeometryExtension'
    GeometryIntExtension = 'Part::GeometryIntExtension'
    GeometryMigrationExtension = 'Part::GeometryMigrationExtension'
    GeometryPersistenceExtension = 'Part::GeometryPersistenceExtension'
    GeometryStringExtension = 'Part::GeometryStringExtension'
    Helix = 'Part::Helix'
    ImportBrep = 'Part::ImportBrep'
    ImportIges = 'Part::ImportIges'
    ImportStep = 'Part::ImportStep'
    Line = 'Part::Line'
    Loft = 'Part::Loft'
    Mirroring = 'Part::Mirroring'
    MultiCommon = 'Part::MultiCommon'
    MultiFuse = 'Part::MultiFuse'
    Offset = 'Part::Offset'
    Offset2D = 'Part::Offset2D'
    Part2DObject = 'Part::Part2DObject'
    Part2DObjectPython = 'Part::Part2DObjectPython'
    Plane = 'Part::Plane'
    Polygon = 'Part::Polygon'
    Primitive = 'Part::Primitive'
    Prism = 'Part::Prism'
    PrismExtension = 'Part::PrismExtension'
    PropertyFilletEdges = 'Part::PropertyFilletEdges'
    PropertyGeometryList = 'Part::PropertyGeometryList'
    PropertyPartShape = 'Part::PropertyPartShape'
    PropertyShapeHistory = 'Part::PropertyShapeHistory'
    Refine = 'Part::Refine'
    RegularPolygon = 'Part::RegularPolygon'
    Reverse = 'Part::Reverse'
    Revolution = 'Part::Revolution'
    RuledSurface = 'Part::RuledSurface'
    Section = 'Part::Section'
    Sphere = 'Part::Sphere'
    Spiral = 'Part::Spiral'
    Spline = 'Part::Spline'
    Sweep = 'Part::Sweep'
    Thickness = 'Part::Thickness'
    TopoShape = 'Part::TopoShape'
    Torus = 'Part::Torus'
    Vertex = 'Part::Vertex'
    Wedge = 'Part::Wedge'


class PartDesign:
    AdditiveBox = 'PartDesign::AdditiveBox'
    AdditiveCone = 'PartDesign::AdditiveCone'
    AdditiveCylinder = 'PartDesign::AdditiveCylinder'
    AdditiveEllipsoid = 'PartDesign::AdditiveEllipsoid'
    AdditiveHelix = 'PartDesign::AdditiveHelix'
    AdditiveLoft = 'PartDesign::AdditiveLoft'
    AdditivePipe = 'PartDesign::AdditivePipe'
    AdditivePrism = 'PartDesign::AdditivePrism'
    AdditiveSphere = 'PartDesign::AdditiveSphere'
    AdditiveTorus = 'PartDesign::AdditiveTorus'
    AdditiveWedge = 'PartDesign::AdditiveWedge'
    Body = 'PartDesign::Body'
    Boolean = 'PartDesign::Boolean'
    Box = 'PartDesign::Box'
    Chamfer = 'PartDesign::Chamfer'
    Cone = 'PartDesign::Cone'
    CoordinateSystem = 'PartDesign::CoordinateSystem'
    Cylinder = 'PartDesign::Cylinder'
    Draft = 'PartDesign::Draft'
    DressUp = 'PartDesign::DressUp'
    Ellipsoid = 'PartDesign::Ellipsoid'
    Feature = 'PartDesign::Feature'
    FeatureAddSub = 'PartDesign::FeatureAddSub'
    FeatureAddSubPython = 'PartDesign::FeatureAddSubPython'
    FeatureAdditivePython = 'PartDesign::FeatureAdditivePython'
    FeatureBase = 'PartDesign::FeatureBase'
    FeaturePrimitive = 'PartDesign::FeaturePrimitive'
    FeaturePython = 'PartDesign::FeaturePython'
    FeatureSubtractivePython = 'PartDesign::FeatureSubtractivePython'
    Fillet = 'PartDesign::Fillet'
    Groove = 'PartDesign::Groove'
    Helix = 'PartDesign::Helix'
    Hole = 'PartDesign::Hole'
    Line = 'PartDesign::Line'
    LinearPattern = 'PartDesign::LinearPattern'
    Loft = 'PartDesign::Loft'
    Mirrored = 'PartDesign::Mirrored'
    MultiTransform = 'PartDesign::MultiTransform'
    Pad = 'PartDesign::Pad'
    Pipe = 'PartDesign::Pipe'
    Plane = 'PartDesign::Plane'
    Pocket = 'PartDesign::Pocket'
    Point = 'PartDesign::Point'
    PolarPattern = 'PartDesign::PolarPattern'
    Prism = 'PartDesign::Prism'
    ProfileBased = 'PartDesign::ProfileBased'
    Revolution = 'PartDesign::Revolution'
    Scaled = 'PartDesign::Scaled'
    ShapeBinder = 'PartDesign::ShapeBinder'
    Solid = 'PartDesign::Solid'
    Sphere = 'PartDesign::Sphere'
    SubShapeBinder = 'PartDesign::SubShapeBinder'
    SubtractiveBox = 'PartDesign::SubtractiveBox'
    SubtractiveCone = 'PartDesign::SubtractiveCone'
    SubtractiveCylinder = 'PartDesign::SubtractiveCylinder'
    SubtractiveEllipsoid = 'PartDesign::SubtractiveEllipsoid'
    SubtractiveHelix = 'PartDesign::SubtractiveHelix'
    SubtractiveLoft = 'PartDesign::SubtractiveLoft'
    SubtractivePipe = 'PartDesign::SubtractivePipe'
    SubtractivePrism = 'PartDesign::SubtractivePrism'
    SubtractiveSphere = 'PartDesign::SubtractiveSphere'
    SubtractiveTorus = 'PartDesign::SubtractiveTorus'
    SubtractiveWedge = 'PartDesign::SubtractiveWedge'
    Thickness = 'PartDesign::Thickness'
    Torus = 'PartDesign::Torus'
    Transformed = 'PartDesign::Transformed'
    Wedge = 'PartDesign::Wedge'


class PartDesignGui:
    ViewProvider = 'PartDesignGui::ViewProvider'
    ViewProviderAddSub = 'PartDesignGui::ViewProviderAddSub'
    ViewProviderBase = 'PartDesignGui::ViewProviderBase'
    ViewProviderBody = 'PartDesignGui::ViewProviderBody'
    ViewProviderBoolean = 'PartDesignGui::ViewProviderBoolean'
    ViewProviderChamfer = 'PartDesignGui::ViewProviderChamfer'
    ViewProviderDatum = 'PartDesignGui::ViewProviderDatum'
    ViewProviderDatumCoordinateSystem = 'PartDesignGui::ViewProviderDatumCoordinateSystem'
    ViewProviderDatumLine = 'PartDesignGui::ViewProviderDatumLine'
    ViewProviderDatumPlane = 'PartDesignGui::ViewProviderDatumPlane'
    ViewProviderDatumPoint = 'PartDesignGui::ViewProviderDatumPoint'
    ViewProviderDraft = 'PartDesignGui::ViewProviderDraft'
    ViewProviderDressUp = 'PartDesignGui::ViewProviderDressUp'
    ViewProviderFillet = 'PartDesignGui::ViewProviderFillet'
    ViewProviderGroove = 'PartDesignGui::ViewProviderGroove'
    ViewProviderHelix = 'PartDesignGui::ViewProviderHelix'
    ViewProviderHole = 'PartDesignGui::ViewProviderHole'
    ViewProviderLinearPattern = 'PartDesignGui::ViewProviderLinearPattern'
    ViewProviderLoft = 'PartDesignGui::ViewProviderLoft'
    ViewProviderMirrored = 'PartDesignGui::ViewProviderMirrored'
    ViewProviderMultiTransform = 'PartDesignGui::ViewProviderMultiTransform'
    ViewProviderPad = 'PartDesignGui::ViewProviderPad'
    ViewProviderPipe = 'PartDesignGui::ViewProviderPipe'
    ViewProviderPocket = 'PartDesignGui::ViewProviderPocket'
    ViewProviderPolarPattern = 'PartDesignGui::ViewProviderPolarPattern'
    ViewProviderPrimitive = 'PartDesignGui::ViewProviderPrimitive'
    ViewProviderPython = 'PartDesignGui::ViewProviderPython'
    ViewProviderRevolution = 'PartDesignGui::ViewProviderRevolution'
    ViewProviderScaled = 'PartDesignGui::ViewProviderScaled'
    ViewProviderShapeBinder = 'PartDesignGui::ViewProviderShapeBinder'
    ViewProviderSketchBased = 'PartDesignGui::ViewProviderSketchBased'
    ViewProviderSubShapeBinder = 'PartDesignGui::ViewProviderSubShapeBinder'
    ViewProviderThickness = 'PartDesignGui::ViewProviderThickness'
    ViewProviderTransformed = 'PartDesignGui::ViewProviderTransformed'
    Workbench = 'PartDesignGui::Workbench'


class PartGui:
    PropertyEnumAttacherItem = 'PartGui::PropertyEnumAttacherItem'
    ViewProvider2DObject = 'PartGui::ViewProvider2DObject'
    ViewProvider2DObjectGrid = 'PartGui::ViewProvider2DObjectGrid'
    ViewProvider2DObjectPython = 'PartGui::ViewProvider2DObjectPython'
    ViewProviderAttachExtension = 'PartGui::ViewProviderAttachExtension'
    ViewProviderAttachExtensionPython = 'PartGui::ViewProviderAttachExtensionPython'
    ViewProviderBoolean = 'PartGui::ViewProviderBoolean'
    ViewProviderBox = 'PartGui::ViewProviderBox'
    ViewProviderChamfer = 'PartGui::ViewProviderChamfer'
    ViewProviderCircleParametric = 'PartGui::ViewProviderCircleParametric'
    ViewProviderCompound = 'PartGui::ViewProviderCompound'
    ViewProviderConeParametric = 'PartGui::ViewProviderConeParametric'
    ViewProviderCurveNet = 'PartGui::ViewProviderCurveNet'
    ViewProviderCustom = 'PartGui::ViewProviderCustom'
    ViewProviderCustomPython = 'PartGui::ViewProviderCustomPython'
    ViewProviderCylinderParametric = 'PartGui::ViewProviderCylinderParametric'
    ViewProviderEllipseParametric = 'PartGui::ViewProviderEllipseParametric'
    ViewProviderEllipsoid = 'PartGui::ViewProviderEllipsoid'
    ViewProviderExtrusion = 'PartGui::ViewProviderExtrusion'
    ViewProviderFace = 'PartGui::ViewProviderFace'
    ViewProviderFillet = 'PartGui::ViewProviderFillet'
    ViewProviderHelixParametric = 'PartGui::ViewProviderHelixParametric'
    ViewProviderImport = 'PartGui::ViewProviderImport'
    ViewProviderLineParametric = 'PartGui::ViewProviderLineParametric'
    ViewProviderLoft = 'PartGui::ViewProviderLoft'
    ViewProviderMirror = 'PartGui::ViewProviderMirror'
    ViewProviderMultiCommon = 'PartGui::ViewProviderMultiCommon'
    ViewProviderMultiFuse = 'PartGui::ViewProviderMultiFuse'
    ViewProviderOffset = 'PartGui::ViewProviderOffset'
    ViewProviderOffset2D = 'PartGui::ViewProviderOffset2D'
    ViewProviderPart = 'PartGui::ViewProviderPart'
    ViewProviderPartExt = 'PartGui::ViewProviderPartExt'
    ViewProviderPlaneParametric = 'PartGui::ViewProviderPlaneParametric'
    ViewProviderPointParametric = 'PartGui::ViewProviderPointParametric'
    ViewProviderPrimitive = 'PartGui::ViewProviderPrimitive'
    ViewProviderPrism = 'PartGui::ViewProviderPrism'
    ViewProviderPython = 'PartGui::ViewProviderPython'
    ViewProviderRefine = 'PartGui::ViewProviderRefine'
    ViewProviderRegularPolygon = 'PartGui::ViewProviderRegularPolygon'
    ViewProviderReverse = 'PartGui::ViewProviderReverse'
    ViewProviderRevolution = 'PartGui::ViewProviderRevolution'
    ViewProviderRuledSurface = 'PartGui::ViewProviderRuledSurface'
    ViewProviderSphereParametric = 'PartGui::ViewProviderSphereParametric'
    ViewProviderSpiralParametric = 'PartGui::ViewProviderSpiralParametric'
    ViewProviderSpline = 'PartGui::ViewProviderSpline'
    ViewProviderSplineExtension = 'PartGui::ViewProviderSplineExtension'
    ViewProviderSplineExtensionPython = 'PartGui::ViewProviderSplineExtensionPython'
    ViewProviderSweep = 'PartGui::ViewProviderSweep'
    ViewProviderThickness = 'PartGui::ViewProviderThickness'
    ViewProviderTorusParametric = 'PartGui::ViewProviderTorusParametric'
    ViewProviderWedge = 'PartGui::ViewProviderWedge'
    Workbench = 'PartGui::Workbench'


class Path:
    Area = 'Path::Area'
    Command = 'Path::Command'
    Feature = 'Path::Feature'
    FeatureArea = 'Path::FeatureArea'
    FeatureAreaPython = 'Path::FeatureAreaPython'
    FeatureAreaView = 'Path::FeatureAreaView'
    FeatureAreaViewPython = 'Path::FeatureAreaViewPython'
    FeatureCompound = 'Path::FeatureCompound'
    FeatureCompoundPython = 'Path::FeatureCompoundPython'
    FeaturePython = 'Path::FeaturePython'
    FeatureShape = 'Path::FeatureShape'
    FeatureShapePython = 'Path::FeatureShapePython'
    PropertyPath = 'Path::PropertyPath'
    PropertyTool = 'Path::PropertyTool'
    PropertyTooltable = 'Path::PropertyTooltable'
    Tool = 'Path::Tool'
    Toolpath = 'Path::Toolpath'
    Tooltable = 'Path::Tooltable'
    Voronoi = 'Path::Voronoi'
    VoronoiCell = 'Path::VoronoiCell'
    VoronoiEdge = 'Path::VoronoiEdge'
    VoronoiVertex = 'Path::VoronoiVertex'


class PathGui:
    ViewProviderArea = 'PathGui::ViewProviderArea'
    ViewProviderAreaPython = 'PathGui::ViewProviderAreaPython'
    ViewProviderAreaView = 'PathGui::ViewProviderAreaView'
    ViewProviderAreaViewPython = 'PathGui::ViewProviderAreaViewPython'
    ViewProviderPath = 'PathGui::ViewProviderPath'
    ViewProviderPathCompound = 'PathGui::ViewProviderPathCompound'
    ViewProviderPathCompoundPython = 'PathGui::ViewProviderPathCompoundPython'
    ViewProviderPathPython = 'PathGui::ViewProviderPathPython'
    ViewProviderPathShape = 'PathGui::ViewProviderPathShape'


class PathSimulator:
    PathSim = 'PathSimulator::PathSim'


class Points:
    Feature = 'Points::Feature'
    FeatureCustom = 'Points::FeatureCustom'
    FeaturePython = 'Points::FeaturePython'
    PropertyCurvatureList = 'Points::PropertyCurvatureList'
    PropertyGreyValue = 'Points::PropertyGreyValue'
    PropertyGreyValueList = 'Points::PropertyGreyValueList'
    PropertyNormalList = 'Points::PropertyNormalList'
    PropertyPointKernel = 'Points::PropertyPointKernel'
    Structured = 'Points::Structured'
    StructuredCustom = 'Points::StructuredCustom'


class PointsGui:
    ViewProviderPoints = 'PointsGui::ViewProviderPoints'
    ViewProviderPython = 'PointsGui::ViewProviderPython'
    ViewProviderScattered = 'PointsGui::ViewProviderScattered'
    ViewProviderStructured = 'PointsGui::ViewProviderStructured'
    Workbench = 'PointsGui::Workbench'


class Raytracing:
    LuxFeature = 'Raytracing::LuxFeature'
    LuxProject = 'Raytracing::LuxProject'
    RayFeature = 'Raytracing::RayFeature'
    RayProject = 'Raytracing::RayProject'
    RaySegment = 'Raytracing::RaySegment'


class RaytracingGui:
    ViewProviderLux = 'RaytracingGui::ViewProviderLux'
    ViewProviderPovray = 'RaytracingGui::ViewProviderPovray'
    Workbench = 'RaytracingGui::Workbench'


class ReverseEngineeringGui:
    Workbench = 'ReverseEngineeringGui::Workbench'


class Robot:
    Edge2TracObject = 'Robot::Edge2TracObject'
    PropertyTrajectory = 'Robot::PropertyTrajectory'
    Robot6Axis = 'Robot::Robot6Axis'
    RobotObject = 'Robot::RobotObject'
    Trajectory = 'Robot::Trajectory'
    TrajectoryCompound = 'Robot::TrajectoryCompound'
    TrajectoryDressUpObject = 'Robot::TrajectoryDressUpObject'
    TrajectoryObject = 'Robot::TrajectoryObject'
    Waypoint = 'Robot::Waypoint'


class RobotGui:
    ViewProviderEdge2TracObject = 'RobotGui::ViewProviderEdge2TracObject'
    ViewProviderRobotObject = 'RobotGui::ViewProviderRobotObject'
    ViewProviderTrajectory = 'RobotGui::ViewProviderTrajectory'
    ViewProviderTrajectoryCompound = 'RobotGui::ViewProviderTrajectoryCompound'
    ViewProviderTrajectoryDressUp = 'RobotGui::ViewProviderTrajectoryDressUp'
    Workbench = 'RobotGui::Workbench'


class SIM:
    Coin3D_Quarter_Quarter = 'SIM::Coin3D::Quarter::Quarter'


class SMDS:
    MeshCell = 'SMDS_MeshCell'
    MeshEdge = 'SMDS_MeshEdge'
    MeshFace = 'SMDS_MeshFace'
    MeshVolume = 'SMDS_MeshVolume'


class SMESH:
    Block = 'SMESH_Block'


class Sandbox:
    DocumentProtector = 'Sandbox::DocumentProtector'
    SandboxObject = 'Sandbox::SandboxObject'


class SandboxGui:
    Workbench = 'SandboxGui::Workbench'


class Sketcher:
    Constraint = 'Sketcher::Constraint'
    ExternalGeometryExtension = 'Sketcher::ExternalGeometryExtension'
    ExternalGeometryFacade = 'Sketcher::ExternalGeometryFacade'
    GeometryFacade = 'Sketcher::GeometryFacade'
    PropertyConstraintList = 'Sketcher::PropertyConstraintList'
    Sketch = 'Sketcher::Sketch'
    SketchGeometryExtension = 'Sketcher::SketchGeometryExtension'
    SketchObject = 'Sketcher::SketchObject'
    SketchObjectPython = 'Sketcher::SketchObjectPython'
    SketchObjectSF = 'Sketcher::SketchObjectSF'
    SolverGeometryExtension = 'Sketcher::SolverGeometryExtension'


class SketcherGui:
    PropertyConstraintListItem = 'SketcherGui::PropertyConstraintListItem'
    ViewProviderCustom = 'SketcherGui::ViewProviderCustom'
    ViewProviderCustomPython = 'SketcherGui::ViewProviderCustomPython'
    ViewProviderPython = 'SketcherGui::ViewProviderPython'
    ViewProviderSketch = 'SketcherGui::ViewProviderSketch'
    ViewProviderSketchGeometryExtension = 'SketcherGui::ViewProviderSketchGeometryExtension'
    Workbench = 'SketcherGui::Workbench'


class Spreadsheet:
    PropertyColumnWidths = 'Spreadsheet::PropertyColumnWidths'
    PropertyRowHeights = 'Spreadsheet::PropertyRowHeights'
    PropertySheet = 'Spreadsheet::PropertySheet'
    PropertySpreadsheetQuantity = 'Spreadsheet::PropertySpreadsheetQuantity'
    Sheet = 'Spreadsheet::Sheet'
    SheetPython = 'Spreadsheet::SheetPython'


class SpreadsheetGui:
    SheetView = 'SpreadsheetGui::SheetView'
    ViewProviderSheet = 'SpreadsheetGui::ViewProviderSheet'
    Workbench = 'SpreadsheetGui::Workbench'


class StartGui:
    Workbench = 'StartGui::Workbench'


class Surface:
    Cut = 'Surface::Cut'
    Extend = 'Surface::Extend'
    Filling = 'Surface::Filling'
    GeomFillSurface = 'Surface::GeomFillSurface'
    Sections = 'Surface::Sections'
    Sewing = 'Surface::Sewing'


class SurfaceGui:
    ViewProviderExtend = 'SurfaceGui::ViewProviderExtend'
    ViewProviderFilling = 'SurfaceGui::ViewProviderFilling'
    ViewProviderGeomFillSurface = 'SurfaceGui::ViewProviderGeomFillSurface'
    ViewProviderSections = 'SurfaceGui::ViewProviderSections'
    Workbench = 'SurfaceGui::Workbench'


class TechDraw:
    CenterLine = 'TechDraw::CenterLine'
    CosmeticEdge = 'TechDraw::CosmeticEdge'
    CosmeticExtension = 'TechDraw::CosmeticExtension'
    CosmeticExtensionPython = 'TechDraw::CosmeticExtensionPython'
    CosmeticVertex = 'TechDraw::CosmeticVertex'
    DrawGeomHatch = 'TechDraw::DrawGeomHatch'
    DrawHatch = 'TechDraw::DrawHatch'
    DrawLeaderLine = 'TechDraw::DrawLeaderLine'
    DrawLeaderLinePython = 'TechDraw::DrawLeaderLinePython'
    DrawPage = 'TechDraw::DrawPage'
    DrawPagePython = 'TechDraw::DrawPagePython'
    DrawParametricTemplate = 'TechDraw::DrawParametricTemplate'
    DrawProjGroup = 'TechDraw::DrawProjGroup'
    DrawProjGroupItem = 'TechDraw::DrawProjGroupItem'
    DrawRichAnno = 'TechDraw::DrawRichAnno'
    DrawRichAnnoPython = 'TechDraw::DrawRichAnnoPython'
    DrawSVGTemplate = 'TechDraw::DrawSVGTemplate'
    DrawTemplate = 'TechDraw::DrawTemplate'
    DrawTemplatePython = 'TechDraw::DrawTemplatePython'
    DrawTile = 'TechDraw::DrawTile'
    DrawTilePython = 'TechDraw::DrawTilePython'
    DrawTileWeld = 'TechDraw::DrawTileWeld'
    DrawTileWeldPython = 'TechDraw::DrawTileWeldPython'
    DrawView = 'TechDraw::DrawView'
    DrawViewAnnotation = 'TechDraw::DrawViewAnnotation'
    DrawViewArch = 'TechDraw::DrawViewArch'
    DrawViewBalloon = 'TechDraw::DrawViewBalloon'
    DrawViewClip = 'TechDraw::DrawViewClip'
    DrawViewCollection = 'TechDraw::DrawViewCollection'
    DrawViewDetail = 'TechDraw::DrawViewDetail'
    DrawViewDimExtent = 'TechDraw::DrawViewDimExtent'
    DrawViewDimension = 'TechDraw::DrawViewDimension'
    DrawViewDraft = 'TechDraw::DrawViewDraft'
    DrawViewImage = 'TechDraw::DrawViewImage'
    DrawViewMulti = 'TechDraw::DrawViewMulti'
    DrawViewMultiPython = 'TechDraw::DrawViewMultiPython'
    DrawViewPart = 'TechDraw::DrawViewPart'
    DrawViewPartPython = 'TechDraw::DrawViewPartPython'
    DrawViewPython = 'TechDraw::DrawViewPython'
    DrawViewSection = 'TechDraw::DrawViewSection'
    DrawViewSpreadsheet = 'TechDraw::DrawViewSpreadsheet'
    DrawViewSymbol = 'TechDraw::DrawViewSymbol'
    DrawViewSymbolPython = 'TechDraw::DrawViewSymbolPython'
    DrawWeldSymbol = 'TechDraw::DrawWeldSymbol'
    DrawWeldSymbolPython = 'TechDraw::DrawWeldSymbolPython'
    GeomFormat = 'TechDraw::GeomFormat'
    LandmarkDimension = 'TechDraw::LandmarkDimension'
    PropertyCenterLineList = 'TechDraw::PropertyCenterLineList'
    PropertyCosmeticEdgeList = 'TechDraw::PropertyCosmeticEdgeList'
    PropertyCosmeticVertexList = 'TechDraw::PropertyCosmeticVertexList'
    PropertyGeomFormatList = 'TechDraw::PropertyGeomFormatList'


class TechDrawGui:
    MDIViewPage = 'TechDrawGui::MDIViewPage'
    ViewProviderAnnotation = 'TechDrawGui::ViewProviderAnnotation'
    ViewProviderArch = 'TechDrawGui::ViewProviderArch'
    ViewProviderBalloon = 'TechDrawGui::ViewProviderBalloon'
    ViewProviderCosmeticExtension = 'TechDrawGui::ViewProviderCosmeticExtension'
    ViewProviderDimension = 'TechDrawGui::ViewProviderDimension'
    ViewProviderDraft = 'TechDrawGui::ViewProviderDraft'
    ViewProviderDrawingView = 'TechDrawGui::ViewProviderDrawingView'
    ViewProviderGeomHatch = 'TechDrawGui::ViewProviderGeomHatch'
    ViewProviderHatch = 'TechDrawGui::ViewProviderHatch'
    ViewProviderImage = 'TechDrawGui::ViewProviderImage'
    ViewProviderLeader = 'TechDrawGui::ViewProviderLeader'
    ViewProviderPage = 'TechDrawGui::ViewProviderPage'
    ViewProviderProjGroup = 'TechDrawGui::ViewProviderProjGroup'
    ViewProviderProjGroupItem = 'TechDrawGui::ViewProviderProjGroupItem'
    ViewProviderRichAnno = 'TechDrawGui::ViewProviderRichAnno'
    ViewProviderSpreadsheet = 'TechDrawGui::ViewProviderSpreadsheet'
    ViewProviderSymbol = 'TechDrawGui::ViewProviderSymbol'
    ViewProviderTemplate = 'TechDrawGui::ViewProviderTemplate'
    ViewProviderTile = 'TechDrawGui::ViewProviderTile'
    ViewProviderViewClip = 'TechDrawGui::ViewProviderViewClip'
    ViewProviderViewPart = 'TechDrawGui::ViewProviderViewPart'
    ViewProviderViewSection = 'TechDrawGui::ViewProviderViewSection'
    ViewProviderWeld = 'TechDrawGui::ViewProviderWeld'
    Workbench = 'TechDrawGui::Workbench'


class WebGui:
    Workbench = 'WebGui::Workbench'


class voidGui:
    SoFCDB = 'voidGui::SoFCDB'


class voidSIM:
    Coin3D_Quarter_SoQTQuarterAdaptor = 'voidSIM::Coin3D::Quarter::SoQTQuarterAdaptor'


class voidSMESH:
    Block = 'voidSMESH_Block'
